@@ -35,30 +35,30 @@ class LogChainer:
 	Entrypoint for initializing the log chain.
 	"""
 
-	def __init__(self, args = {}, **kwargs):
+	def __init__(self, **kwargs):
 		"""
-		@param args: dict
+		@param named args
 		"""
+		kwargs.setdefault("secret", secrets.token_urlsafe(128))
+		kwargs.setdefault("seed", secrets.token_urlsafe())
 
-		defaultParams = {
-			"stream": None,
-			"formatterCls": formatters.Basic,
-			"secret": secrets.token_urlsafe(128),
-			"seed": secrets.token_urlsafe(),
-			"format": "%(timestamp)s %(levelLetters)s %(fileLine)-15s %(funcName)-15s %(message)-60s |%(signature)s",
-			"verbosity": 0,
-			"timestampUtc": False,
-			"timestampFmt": "iso", # or strftime
-			"timestampPrecision": "milliseconds"
-		}
-		self.params = SimpleNamespace(**{**defaultParams, **args, **kwargs})
-		self.formatter = self.params.formatterCls(self.params)
+		self.verbosity = kwargs.get("verbosity", 0)
+		self.stream = kwargs.get("stream", None)
+		self.secret = kwargs["secret"]
+		self.seed = kwargs["seed"]
+		self.formatterCls = kwargs.get("formatterCls", formatters.Basic)
 
+		self.formatter = self.formatterCls(kwargs)
+		self.extractFunc = kwargs.get("extractSignature", self.formatter.extractSignature)
+
+		# Remaining unused args
+		# if kwargs:
+		# 	raise ValueError('Unrecognised argument(s): %s' % keys)
 
 	def initLogging(self):
-		aLevel = VerbosityToLevel.get(self.params.verbosity, logging.DEBUG)
+		aLevel = VerbosityToLevel.get(self.verbosity, logging.DEBUG)
 
-		logging.basicConfig(level = aLevel, stream = self.params.stream)
+		logging.basicConfig(level = aLevel, stream = self.stream)
 
 		handler = logging.getLogger().handlers[0]
 		handler.setFormatter(self.formatter)
@@ -72,12 +72,11 @@ class LogChainer:
 		- last consistent line
 		- first inconsistent line
 		"""
-		extractFunc = getattr(self.params, "extractSignature", self.formatter.extractSignature)
 
 		# TODO, verify the last line somehow
 		for prevLine, line in zip(iLogChain, iLogChain[1:]):
-			aStoredSign = extractFunc(line)
-			aComputedSign = self.formatter.sign(prevLine, self.params.secret)
+			aStoredSign = self.extractFunc(line)
+			aComputedSign = self.formatter.sign(prevLine, self.secret)
 
 			isValid = hmac.compare_digest(aStoredSign, aComputedSign)
 
