@@ -26,7 +26,7 @@ class Json(Basic):
 		defaultFields = {"signature", "timestamp", "levelno", "fileLine", "msg",
 		                 "process", "processName", "thread", "threadName"}
 
-		self.fields = getattr(params, "fields", defaultFields) | getattr(params, "extraFields", set())
+		self.fields = params.get("fields", defaultFields) | params.get("extraFields", set())
 
 
 	def stringify(self, record):
